
# Playing with overrides, declaration order and appending like this is
# too subtle and unreliable.

# The fix is to let the user play with "standard" CXXFLAGS and LDFLAGS
# on the command line on one hand, and to have our own, private
# OS_*_FLAGS, COMPILER_*_FLAGS, LINKER_*_FLAGS on the other hand.


# Defaults
COMPILER?=gcc
LINKER?=gnu
OS?=linux


include ${MKINCLUDES}/${COMPILER}-compiler.mk

# order matters: os.mk is likely to define the right linker to use
include ${MKINCLUDES}/${OS}-os.mk
include ${MKINCLUDES}/${LINKER}-linker.mk


ifneq ($(origin CUSTOM), undefined)
custom_files=${CUSTOM:%=${MKINCLUDES}/%.mk}
include $(custom_files)
endif


# Forward flags from the compiler to the linker
# e.g.                -soname          ${LIB_CAROB_SONAME}
# becomes:   -Xlinker -soname -Xlinker ${LIB_CAROB_SONAME}
# See useful references in defaults.mk

MK_LDFLAGS += ${INDIRECT_LDFLAGS:%=${LD_FORWARDER} %}
SHARED_LDFLAGS += ${SHARED_INDIRECT_LDFLAGS:%=${LD_FORWARDER} %}
TEST_LDFLAGS += ${TEST_INDIRECT_LDFLAGS:%=${LD_FORWARDER} %}


# Append MK_ flags from .mk files

override CPPFLAGS += ${MK_CPPFLAGS}
override CXXFLAGS += ${MK_CXXFLAGS}
override LDFLAGS += ${MK_LDFLAGS}
override LDLIBS += ${MK_LDLIBS}
