/*
 * Sequoia: Database clustering technology.
 * Copyright (C) 2005-2006 Continuent, Inc.
 * Contact: sequoia@continuent.org
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Initial developer(s): Gilles Rayrat
 * Contributor(s): 
 */

#ifndef TESTONVALIDCONNECTION_H_
#define TESTONVALIDCONNECTION_H_


#include <cppunit/TestFixture.h>
#include <cppunit/TestCase.h>
#include <cppunit/TestSuite.h>
#include <cppunit/TestCaller.h>

#include "Connection.hpp"

/**
 * Test super class for running tests on a valid connection to a
 * controller.  Defines setUp() and tearDown() functions to connect to
 * a controller (by default: host "localhost", db "myDB", user "user",
 * etc. Modify default ctor below or even ConnectionSetup.cpp
 * according to your needs.
 * 
 * Derive this class to get connected to a controller for free.  No
 * testing is done here! A controller *MUST* be running at the given
 * address for test success.
 */
class ConnectionSetup : CppUnit::TestFixture
{
public:
  /** Default first controller host used for the tests */
  const static std::wstring& DEFAULT_HOST1;
  /** Default controller host #2 used for the tests */
  const static std::wstring& DEFAULT_HOST2;
  /** Default first controller port used for the tests */
  const static int          DEFAULT_PORT1;
  /** Default controller port #2 used for the tests */
  const static int          DEFAULT_PORT2;
  /** Default vdb used for the tests */
  const static std::wstring& DEFAULT_DB;
  /** Default vdb user for the tests */
  const static std::wstring& DEFAULT_USER;
  /** Default vdb password for the tests */
  const static std::wstring& DEFAULT_PASSWD;
  /** Default vdb policy for the tests */
  const static CarobNS::ConnectPolicy DEFAULT_POLICY;
  /** Default ping delay in milliseconds */
  const static int          DEFAULT_PING_DELAY;
  /** Default controller timeout in milliseconds */
  const static int          DEFAULT_CONTROLLER_TIMEOUT;
  /** Default connection persistency */
  const static bool         DEFAULT_CONNECTION_PERSISTENCY;
  /** Default retrieval of sql warnings */
  const static bool         DEFAULT_RETRIEVE_SQL_WARNINGS;

  /** Creates the connection and connects to the running local controller. */
  virtual void setUp();
  /** Destroys the connection if applicable */
  virtual void tearDown();

  /** Probably throws or at least logs errors if connection has been
      left in a corrupted state by some test */
  void testConnection();

  /** Valid connection on which data transferts are to be done */
  CarobNS::Connection*       connectionPtr;
};

void dropTableIfExists(CarobNS::Connection *conn_p, const std::wstring& tableName);
void createOrReplaceTable(CarobNS::Connection *conn_p, const std::wstring& tableName, const std::wstring& tableType);

#endif /*TESTONVALIDCONNECTION_H_*/
